@@ -61,9 +61,9 @@ class Linear(Module):
         return self.linear.bias
 
     def forward(self, net: Tensor) -> Tensor:
-        if self.pruner is None:
-            return self.linear(net)
-        weight = self.pruner(self.linear.weight)
+        weight = self.linear.weight
+        if self.pruner is not None:
+            weight = self.pruner(weight)
         return F.linear(net, weight, self.linear.bias)
 
     def reset_parameters(self) -> None:
@@ -545,8 +545,8 @@ class DNDF(Module):
             increment_mask = np.repeat(arange, 2)
             increment_mask += np.tile([0, self._num_internals], num_local_internals)
             increment_mask = np.repeat(increment_mask, num_repeat)
-            increment_mask = torch.from_numpy(increment_mask.astype(np_int_type))
-            increment_indices.append(increment_mask)
+            increment_mask_ = torch.from_numpy(increment_mask.astype(np_int_type))
+            increment_indices.append(increment_mask_)
         self.increment_masks: Tensor
         self.register_buffer("tree_arange", torch.arange(num_tree)[..., None, None])
         self.register_buffer("ones", torch.stack(ones_list))
