@@ -1028,11 +1028,9 @@ class Trainer(MonitoredMixin):
             )
         self.state.inject_loader(tr_loader)
         # sample weights
-        if tr_weights is not None:
-            tr_weights = to_torch(tr_weights)
-        if cv_weights is not None:
-            cv_weights = to_torch(cv_weights)
-        self.tr_weights, self.cv_weights = tr_weights, cv_weights
+        tr_weights_ = None if tr_weights is None else to_torch(tr_weights)
+        cv_weights_ = None if cv_weights is None else to_torch(cv_weights)
+        self.tr_weights, self.cv_weights = tr_weights_, cv_weights_
         # optimizer
         self._init_optimizers()
         # deep speed
@@ -1046,6 +1044,18 @@ class Trainer(MonitoredMixin):
         self._monitor = TrainMonitor.monitor(self, **monitor_config)
         # train
         self.model.info()
+        show_summary = self.show_summary
+        if show_summary is None:
+            show_summary = not self.tqdm_settings.in_distributed
+        if show_summary:
+            next_item = next(iter(self.tr_loader_copy))
+            if self.tr_loader_copy.return_indices:
+                assert isinstance(next_item, tuple)
+                sample_batch = next_item[0]
+            else:
+                assert isinstance(next_item, dict)
+                sample_batch = next_item
+            summary(self.model, sample_batch)
         self._prepare_log()
         step_tqdm = None
         self._epoch_tqdm: Optional[tqdm] = None
@@ -1085,14 +1095,6 @@ class Trainer(MonitoredMixin):
                 )
                 terminate = True
             if terminate:
-                if os.path.isdir(self.checkpoint_folder):
-                    if not self.deepspeed:
-                        self.log_msg(  # type: ignore
-                            "rolling back to the best checkpoint",
-                            self.info_prefix,
-                            3,
-                        )
-                    has_ckpt = self.restore_checkpoint()
                 break
             if self.use_tqdm:
                 assert self._epoch_tqdm is not None
@@ -1103,6 +1105,15 @@ class Trainer(MonitoredMixin):
                 step_tqdm.close()
             assert self._epoch_tqdm is not None
             self._epoch_tqdm.close()
+        # restore
+        if os.path.isdir(self.checkpoint_folder):
+            if not self.deepspeed:
+                self.log_msg(  # type: ignore
+                    "rolling back to the best checkpoint",
+                    self.info_prefix,
+                    3,
+                )
+            has_ckpt = self.restore_checkpoint()
         # finalize
         self.state.set_terminate()
         outputs = self._generate_binary_threshold()
@@ -1129,6 +1140,7 @@ class Trainer(MonitoredMixin):
                 logits = None
             else:
                 logits = probabilities
+            assert probabilities is not None
             outputs.results["predictions"] = self.inference.predict_with(probabilities)
         else:
             if not is_custom_loader:
